@@ -1,7 +1,5 @@
 #!/usr/bin/env perl
 
-# PERL_FUTURE_DEBUG=1 perl eg/math.pl
-
 use curry;
 use Future::IO::Impl::IOAsync;
 use MIDI::RtController ();
@@ -13,6 +11,7 @@ my $output_name = shift || 'fluid';    # fluidsynth
 my $rtc = MIDI::RtController->new(
     input  => $input_name,
     output => $output_name,
+    verbose => 1,
 );
 
 my $rtf = MIDI::RtController::Filter::Math->new(rtc => $rtc);
